@@ -3,13 +3,13 @@
 /**
  * mailbox_display.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Copyright (c) 1999-2004 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This contains functions that display mailbox information, such as the
  * table row that has sender, date, subject, etc...
  *
- * $Id: mailbox_display.php,v 1.321.2.9 2003/06/29 20:14:58 stekkel Exp $
+ * $Id: mailbox_display.php,v 1.321.2.20 2004/04/19 16:21:53 jangliss Exp $
  */
 
 require_once(SM_PATH . 'functions/strings.php');
@@ -17,27 +17,31 @@ require_once(SM_PATH . 'functions/html.php');
 require_once(SM_PATH . 'class/html.class.php');
 require_once(SM_PATH . 'functions/imap_mailbox.php');
 
-/* Default value for page_selector_max. */
+/* Constants:
+ *   PG_SEL_MAX:   default value for page_selector_max
+ *   SUBJ_TRIM_AT: the length at which we trim off subjects
+ */
 define('PG_SEL_MAX', 10);
+define('SUBJ_TRIM_AT', 55);
 
 function elapsed($start)
 {
    $end = microtime();
    list($start2, $start1) = explode(" ", $start);
    list($end2, $end1) = explode(" ", $end);
-  $diff1 = $end1 - $start1;
+   $diff1 = $end1 - $start1;
    $diff2 = $end2 - $start2;
    if( $diff2 < 0 ){
        $diff1 -= 1;
        $diff2 += 1.0;
-  }
+   }
    return $diff2 + $diff1;
 }
 
 function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                           $start_msg, $where, $what) {
     global $checkall,
-           $color, $msgs, $msort, $td_str, $msg, 
+           $color, $msgs, $msort, $td_str, $msg,
            $default_use_priority,
            $message_highlight_list,
            $index_order,
@@ -74,7 +78,7 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
        $msg['FROM'] = $msg['TO'];
     }
     $msg['FROM'] = parseAddress($msg['FROM'],1);
-    
+
        /*
         * This is done in case you're looking into Sent folders,
         * because you can have multiple receivers.
@@ -95,9 +99,6 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
         }
     }
     $senderName = str_replace('&nbsp;',' ',$senderName);
-    $msg['SUBJECT'] = decodeHeader($msg['SUBJECT']);
-    $subject = processSubject($msg['SUBJECT'], $indent_array[$msg['ID']]);
-    $subject = str_replace('&nbsp;',' ',$subject);    
     echo html_tag( 'tr','','','','VALIGN="top"') . "\n";
 
     if (isset($msg['FLAG_FLAGGED']) && ($msg['FLAG_FLAGGED'] == true)) {
@@ -134,7 +135,7 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
     } else {
         $searchstr = '';
     }
-    
+
     if (is_array($message_highlight_list) && count($message_highlight_list)) {
         $msg['TO'] = parseAddress($msg['TO']);
         $msg['CC'] = parseAddress($msg['CC']);
@@ -153,8 +154,8 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                         case('CC'):
                         case('FROM'):
                             foreach ($msg[$match_type] as $address) {
-                                $address[0] = decodeHeader($address[0]);
-                                $address[1] = decodeHeader($address[1]);
+                                $address[0] = decodeHeader($address[0], true, false);
+                                $address[1] = decodeHeader($address[1], true, false);
                                 if (strstr('^^' . strtolower($address[0]), $high_val) ||
                                     strstr('^^' . strtolower($address[1]), $high_val)) {
                                     $hlt_color = $message_highlight_list_part['color'];
@@ -163,9 +164,10 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                             }
                             break;
                         default:
-                            if (strstr('^^' . strtolower($msg[$match_type]), $high_val)) {
+                            $headertest = strtolower(decodeHeader($msg[$match_type], true, false));
+                            if (strstr('^^' . $headertest, $high_val)) {
                                 $hlt_color = $message_highlight_list_part['color'];
-                                break 3; 
+                                break 3;
                             }
                             break;
                     }
@@ -179,6 +181,9 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
     }
     $checked = ($checkall == 1) ? ' CHECKED' : '';
     $col = 0;
+    $msg['SUBJECT'] = decodeHeader($msg['SUBJECT']);
+    $subject = processSubject($msg['SUBJECT'], $indent_array[$msg['ID']]);
+    $subject = str_replace('&nbsp;',' ',$subject);
     if (sizeof($index_order)) {
         foreach ($index_order as $index_order_part) {
             switch ($index_order_part) {
@@ -229,57 +234,57 @@ function printMessageInfo($imapConnection, $t, $not_last=true, $key, $mailbox,
                 echo html_tag( 'td', $td_str, 'left', $hlt_color );
                 break;
             case 5: /* flags */
-                $stuff = false;
                 $td_str = "<b><small>";
 
                 if (isset($msg['FLAG_FLAGGED']) && $msg['FLAG_FLAGGED'] == true) {
-                    $td_str .= _('<IMG SRC="../plugins/msg_flags/flagged.gif" border="0" height="10" width="10"> ');
+                		$msg_alt = _("This message is Flagged");
+                    $td_str .= '<IMG SRC="../plugins/msg_flags/flagged.gif" border="0" height="10" width="10" alt="'. $msg_alt .'" title="'. $msg_alt .'"> ';
                 }
                 if ($default_use_priority) {
                     if ( ($msg['PRIORITY'] == 1) || ($msg['PRIORITY'] == 2) ) {
-                        $td_str .= '<IMG SRC="../plugins/msg_flags/prio_high.gif" border="0" height="10" width="5"> ';
+                    		$msg_alt = _("This message is High Priority");
+                        $td_str .= '<IMG SRC="../plugins/msg_flags/prio_high.gif" border="0" height="10" width="5" alt="'. $msg_alt .'" title="'. $msg_alt .'"> ';
                     }
-                    else if ($msg['PRIORITY'] == 5) {
-                        $td_str .= '<IMG SRC="../plugins/msg_flags/prio_low.gif" border="0" height="10" width="5"> ';
+                    elseif ($msg['PRIORITY'] == 5) {
+                    		$msg_alt = _("This message is Low Priority");
+                        $td_str .= '<IMG SRC="../plugins/msg_flags/prio_low.gif" border="0" height="10" width="5" alt="'. $msg_alt .'" title="'. $msg_alt .'"> ';
                     }
-                    else
-                    {
-                        $td_str .= '<IMG SRC="../plugins/msg_flags/transparent.gif" border="0" width="5"> ';
+                    else {
+                    		$td_str .= '<IMG SRC="../plugins/msg_flags/transparent.gif" border="0" height="10" width="5"> ';
                     }
                 }
                 if ($msg['TYPE0'] == 'multipart') {
-                    $td_str .= '<IMG SRC="../plugins/msg_flags/attach.gif" border="0" height="10" width="6">';
+                		$msg_alt = _("This message is Mulitpart");
+                    $td_str .= '<IMG SRC="../plugins/msg_flags/attach.gif" border="0" height="10" width="6" alt="'. $msg_alt .'" title="'. $msg_alt .'">';
                 }
-                else
-                {
-                    $td_str .= '<IMG SRC="../plugins/msg_flags/transparent.gif" border="0" width="6">';
+                else {
+                		$td_str .= '<IMG SRC="../plugins/msg_flags/transparent.gif" border="0" height="10" width="6">';
                 }
 
                 $msg_icon = '';
-                if (!isset($msg['FLAG_SEEN']) || ($msg['FLAG_SEEN']) == false)
-                {
-                    $msg_alt = '(New)';
-                    $msg_title = '(New)';
-                    $msg_icon .= '../plugins/msg_flags/msg_new';
-                }
-                else
-                {
-                    $msg_alt = '(Read)';
-                    $msg_title = '(Read)';
-                    $msg_icon .= "../plugins/msg_flags/msg_read";
-                }
-                if (isset($msg['FLAG_DELETED']) && ($msg['FLAG_DELETED']) == true)
-                {
-                    $msg_icon .= '_deleted';
-                }
-                if (isset($msg['FLAG_ANSWERED']) && ($msg['FLAG_ANSWERED']) == true)
-                {
-                    $msg_icon .= '_reply';
-                }
-                $td_str .= '<IMG SRC="' . $msg_icon . '.gif" border="0" alt="'. $msg_alt . '" title="' . $msg_title . '" height="12" width="18" >';
+
+	              if (!isset($msg['FLAG_SEEN']) || $msg['FLAG_SEEN'] == true) {
+	              		$msg_alt = _("This message is Read");
+	                  $msg_icon .= "../plugins/msg_flags/msg_read";
+	              }
+	              else {
+	              		$msg_alt = _("This message is New");
+	                  $msg_icon .= '../plugins/msg_flags/msg_new';
+	              }
+	              if (isset($msg['FLAG_DELETED']) && $msg['FLAG_DELETED'] == true) {
+	              		$msg_alt .= _(" & Deleted");
+	                  $msg_icon .= '_deleted';
+	              }
+	              if (isset($msg['FLAG_ANSWERED']) && $msg['FLAG_ANSWERED'] == true) {
+	              		$msg_alt .= _(" & Answered");
+	                  $msg_icon .= '_reply';
+	              }
+
+         				$td_str .= '<IMG SRC="' . $msg_icon . '.gif" border="0" alt="'. $msg_alt . '" title="' . $msg_alt . '" height="12" width="18" ></small></b>';
+
+                $td_str .= '&nbsp;';
                 do_hook("msg_envelope");
                 $td_str .= '</small></b>';
-
                 echo html_tag( 'td',
                                $td_str,
                                'right',
@@ -499,11 +504,11 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
     echo '<table border="0" width="100%" cellpadding="0" cellspacing="0">';
     echo '<tr><td>';
 
-    mail_message_listing_beginning($imapConnection, $mailbox, $sort, 
+    mail_message_listing_beginning($imapConnection, $mailbox, $sort,
                                   $msg_cnt_str, $paginator_str, $start_msg);
     echo '</td></tr>';
     /* line between the button area and the list */
-    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'"></td></tr>';  
+    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'"></td></tr>';
 
     echo '<tr><td>';
     echo '    <table width="100%" cellpadding="1" cellspacing="0" align="center"'.' border="0" bgcolor="'.$color[9].'">';
@@ -512,11 +517,11 @@ function showMessagesForMailbox($imapConnection, $mailbox, $num_msgs,
     echo '<tr><td>';
     printHeader($mailbox, $srt, $color, !$thread_sort_messages);
 
-    displayMessageArray($imapConnection, $num_msgs, $start_msg, 
+    displayMessageArray($imapConnection, $num_msgs, $start_msg,
 		      $msort, $mailbox, $sort, $color, $show_num,0,0);
     echo '</td></tr></table></td></tr></table>';
 
-    mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $color); 
+    mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $color);
     echo '</td></tr></table>';
     //$t = elapsed($start);
     //echo("elapsed time = $t seconds\n");
@@ -706,9 +711,9 @@ function mail_message_listing_beginning ($imapConnection,
                     html_tag( 'table' ,
                         html_tag( 'tr',
                             html_tag( 'td', $paginator, 'left' ) .
-                            html_tag( 'td', $msg_cnt_str, 'right' ) 
+                            html_tag( 'td', $msg_cnt_str, 'right' )
                         )
-                    , '', $color[4], 'border="0" width="100%" cellpadding="1"  cellspacing="0"' ) 
+                    , '', $color[4], 'border="0" width="100%" cellpadding="1"  cellspacing="0"' )
                 , 'left', '', '' )
             , '', $color[0] )
 	    , '', '', 'border="0" width="100%" cellpadding="1"  cellspacing="0"' );
@@ -727,11 +732,11 @@ function mail_message_listing_beginning ($imapConnection,
             )
             . html_tag( 'tr' ) ."\n"
             . html_tag( 'td', '', 'left', '', 'valign="middle" nowrap' );
-            getMbxList($imapConnection);  
-            echo getButton('SUBMIT', 'moveButton',_("Move")) . "\n";   
-            echo getButton('SUBMIT', 'attache',_("Forward")) . "\n";   
+            getMbxList($imapConnection);
+            echo getButton('SUBMIT', 'moveButton',_("Move")) . "\n";
+            echo getButton('SUBMIT', 'attache',_("Forward")) . "\n";
 
-  echo "      </TD>\n"
+  echo "      </small></td>\n"
          . html_tag( 'td', '', 'right', '', 'nowrap' );
 
 
@@ -741,7 +746,7 @@ function mail_message_listing_beginning ($imapConnection,
              .'&nbsp;' . _("mailbox") . "\n";
     }
 
-    echo getButton('SUBMIT', 'markFlagged',_("Flag"));
+		echo getButton('SUBMIT', 'markFlagged',_("Flag"));
     echo getButton('SUBMIT', 'markUnflagged',_("Unflag"));
     echo getButton('SUBMIT', 'markRead',_("Read"));
     echo getButton('SUBMIT', 'markUnread',_("Unread"));
@@ -751,6 +756,9 @@ function mail_message_listing_beginning ($imapConnection,
     } else {
         $location = $php_self;
     }
+
+//    $location = urlencode($location);
+
     echo '<INPUT TYPE="HIDDEN" NAME="location" VALUE="'.$location.'">';
     echo "</TD>\n"
          . "   </TR>\n";
@@ -766,9 +774,9 @@ function mail_message_listing_beginning ($imapConnection,
         }
         echo html_tag( 'tr' ,
                     html_tag( 'td' ,
-                              '&nbsp;<a href=' . $source_url . '?sort='
-                              . "$sort" . '&start_messages=1&set_thread=' . "$set_thread"
-                              . '&mailbox=' . urlencode($mailbox) . '><small>' . $thread_name
+                              '&nbsp;<small><a href="' . $source_url . '?sort='
+                              . "$sort" . '&amp;start_messages=1&amp;set_thread=' . "$set_thread"
+                              . '&amp;mailbox=' . urlencode($mailbox) . '">' . $thread_name
                               . '</a></small>&nbsp;'
                      , '', '', '' )
                  , '', '', '' );
@@ -791,7 +799,7 @@ function mail_message_listing_beginning ($imapConnection,
 function mail_message_listing_end($num_msgs, $paginator_str, $msg_cnt_str, $color) {
   if ($num_msgs) {
     /* space between list and footer */
-    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'" COLSPAN="1">';  
+    echo '<tr><td HEIGHT="5" BGCOLOR="'.$color[4].'" COLSPAN="1">';
 
     echo '</td></tr><tr><td>';
     echo html_tag( 'table',
@@ -823,7 +831,7 @@ function printHeader($mailbox, $sort, $color, $showsort=true) {
     $widths = array(1=>1,2=>25,3=>5,4=>0,5=>1,6=>5);
     $subjectwidth = 100;
     foreach($index_order as $item) {
-        $subjectwidth -= $widths[$item]; 
+        $subjectwidth -= $widths[$item];
     }
 
     foreach ($index_order as $item) {
@@ -981,7 +989,7 @@ function get_paginator_link($box, $start_msg, $use, $text) {
 
     $result = "<A HREF=\"right_main.php?use_mailbox_cache=$use"
             . "&amp;startMessage=$start_msg&amp;mailbox=$box\" "
-            . "TARGET=\"right\">$text</A>";
+            . ">$text</A>";
     return ($result);
 /*
     if (preg_match('/^(.+)\?.+$/',$PHP_SELF,$regs)) {
@@ -992,7 +1000,7 @@ function get_paginator_link($box, $start_msg, $use, $text) {
 
     $result = '<A HREF="'. $source_url . "?use_mailbox_cache=$use"
             . "&amp;startMessage=$start_msg&amp;mailbox=$box\" "
-            . "TARGET=\"right\">$text</A>";
+            . ">$text</A>";
     return ($result);
 */
 }
@@ -1089,8 +1097,8 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
             /* Adjust if the first and second quarters intersect. */
             } else if (($cur_pg - $q2_pgs - ceil($q2_pgs/3)) <= $q1_pgs) {
                 $extra_pgs = $q2_pgs;
-                $extra_pgs -= ceil(($cur_pg - $q1_pgs - 1) * 0.75);
-                $q2_pgs = ceil(($cur_pg - $q1_pgs - 1) * 0.75);
+                $extra_pgs -= ceil(($cur_pg - $q1_pgs - 1) * 3/4);
+                $q2_pgs = ceil(($cur_pg - $q1_pgs - 1) * 3/4);
                 $q3_pgs += ceil($extra_pgs / 2);
                 $q4_pgs += floor($extra_pgs / 2);
 
@@ -1103,10 +1111,10 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
                 $q2_pgs += ceil($extra_pgs / 2);
 
             /* Adjust if the third and fourth quarter intersect. */
-            } else if (($cur_pg + $q3_pgs + 1) >= ($tot_pgs - $q4_pgs + 1)) {
+            } else if (($cur_pg + $q3_pgs) >= ($tot_pgs - $q4_pgs)) {
                 $extra_pgs = $q3_pgs;
-                $extra_pgs -= ceil(($tot_pgs - $cur_pg - $q4_pgs) * 0.75);
-                $q3_pgs = ceil(($tot_pgs - $cur_pg - $q4_pgs) * 0.75);
+                $extra_pgs -= ceil(($tot_pgs - $cur_pg - $q4_pgs) * 3/4);
+                $q3_pgs = ceil(($tot_pgs - $cur_pg - $q4_pgs) * 3/4);
                 $q1_pgs += floor($extra_pgs / 2);
                 $q2_pgs += ceil($extra_pgs / 2);
             }
@@ -1115,9 +1123,10 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
         /*
          * I am leaving this debug code here, commented out, because
          * it is a really nice way to see what the above code is doing.
-         * echo "qts =  $q1_pgs/$q2_pgs/$q3_pgs/$q4_pgs = "
-         *    . ($q1_pgs + $q2_pgs + $q3_pgs + $q4_pgs) . '<br>';
-         */
+	 */
+         // echo "qts =  $q1_pgs/$q2_pgs/$q3_pgs/$q4_pgs = "
+         //     . ($q1_pgs + $q2_pgs + $q3_pgs + $q4_pgs) . '<br>';
+
 
         /* Print out the page links from the compute page quarters. */
 
@@ -1164,14 +1173,14 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
     } else if ($PG_SHOWNUM == 999999) {
         $pg_str = "<A HREF=\"right_main.php?PG_SHOWALL=0"
                 . "&amp;use_mailbox_cache=$use&amp;startMessage=1&amp;mailbox=$box\" "
-                . "TARGET=\"right\">" ._("Paginate") . '</A>' . $spc;
+                . ">" ._("Paginate") . '</A>' . $spc;
     }
 
     /* If necessary, compute the 'show all' string. */
     if (($prv_str != '') || ($nxt_str != '')) {
         $all_str = "<A HREF=\"right_main.php?PG_SHOWALL=1"
                  . "&amp;use_mailbox_cache=$use&amp;startMessage=1&amp;mailbox=$box\" "
-                 . "TARGET=\"right\">" . _("Show All") . '</A>';
+                 . ">" . _("Show All") . '</A>';
     }
 
     /* Last but not least, get the value for the toggle all link. */
@@ -1201,17 +1210,20 @@ function get_paginator_str($box, $start_msg, $end_msg, $num_msgs,
 function processSubject($subject, $threadlevel = 0) {
     global $languages, $squirrelmail_language;
     /* Shouldn't ever happen -- caught too many times in the IMAP functions */
-    if ($subject == '')
+    if ($subject == '') {
         return _("(no subject)");
+    }
 
-    $trim_at = 55;
+    $trim_at = SUBJ_TRIM_AT;
 
     /* if this is threaded, subtract two chars per indentlevel */
-    if($threadlevel > 0 && $threadlevel <= 10)
+    if($threadlevel > 0 && $threadlevel <= 10) {
         $trim_at -= (2*$threadlevel);
+    }
 
-    if (strlen($subject) <= $trim_at)
+    if (strlen($subject) <= $trim_at) {
         return $subject;
+    }
 
     $ent_strlen = $orig_len = strlen($subject);
     $trim_val = $trim_at - 5;
@@ -1220,7 +1232,7 @@ function processSubject($subject, $threadlevel = 0) {
      * see if this is entities-encoded string
      * If so, Iterate through the whole string, find out
      * the real number of characters, and if more
-     * than 55, substr with an updated trim value. 
+     * than 55, substr with an updated trim value.
      */
     $step = $ent_loc = 0;
     while ( $ent_loc < $trim_val && (($ent_loc = strpos($subject, '&', $ent_offset)) !== false) &&
@@ -1229,7 +1241,7 @@ function processSubject($subject, $threadlevel = 0) {
         $ent_offset  = $ent_loc_end+1;
         ++$step;
     }
-    
+
     if (($trim_val > 50) && (strlen($subject) > ($trim_val))&& (strpos($subject,';',$trim_val) < ($trim_val +6))) {
         $i = strpos($subject,';',$trim_val);
         if ($i) {
@@ -1244,13 +1256,19 @@ function processSubject($subject, $threadlevel = 0) {
         function_exists($languages[$squirrelmail_language]['XTRA_CODE'])) {
         return $languages[$squirrelmail_language]['XTRA_CODE']('strimwidth', $subject, $trim_val);
     }
-    return substr($subject, 0, $trim_val) . '...';
+
+    // only print '...' when we're actually dropping part of the subject
+    if(strlen($subject) <= $trim_val) {
+        return $subject;
+    } else {
+        return substr($subject, 0, $trim_val) . '...';
+    }
 }
 
 function getMbxList($imapConnection) {
     global $lastTargetMailbox;
     echo  '         <small>&nbsp;<tt><select name="targetMailbox">';
-    echo sqimap_mailbox_option_list($imapConnection, array(strtolower($lastTargetMailbox)) ); 
+    echo sqimap_mailbox_option_list($imapConnection, array(strtolower($lastTargetMailbox)) );
     echo '         </SELECT></TT>&nbsp;';
 }
 
@@ -1284,7 +1302,7 @@ function getEndMessage($start_msg, $show_num, $num_msgs) {
 
 function handleAsSent($mailbox) {
     global $handleAsSent_result;
- 
+
     /* First check if this is the sent or draft folder. */
     $handleAsSent_result = isSentMailbox($mailbox) || isDraftMailbox($mailbox);
 
