@@ -3,13 +3,13 @@
 /**
  * left_main.php
  *
- * Copyright (c) 1999-2003 The SquirrelMail Project Team
+ * Copyright (c) 1999-2004 The SquirrelMail Project Team
  * Licensed under the GNU GPL. For full terms see the file COPYING.
  *
  * This is the code for the left bar. The left bar shows the folders
  * available, and has cookie information.
  *
- * $Id: left_main.php,v 1.154.2.1 2003/06/24 23:20:12 pdontthink Exp $
+ * $Id: left_main.php,v 1.154.2.12 2004/05/17 16:03:40 stekkel Exp $
  */
 
 /* Path for SquirrelMail required files. */
@@ -50,7 +50,7 @@ function formatMailboxName($imapConnection, $box_array) {
 	$tmp_status = create_unseen_string($real_box, $box_array, $imapConnection, $unseen_type );
 	if ($status !== false) {
 	    $status = $tmp_status;
-	} 
+	}
     }
     list($unseen_string, $unseen) = $status;
     $special_color = ($use_special_folder_color && isSpecialMailbox($real_box));
@@ -65,14 +65,25 @@ function formatMailboxName($imapConnection, $box_array) {
     if ($status !== false) {
 	$line .= '<a href="right_main.php?PG_SHOWALL=0&amp;sort=0&amp;startMessage=1&amp;mailbox='.
                 $mailboxURL.'" TARGET="right" STYLE="text-decoration:none">';
-    } 
+    }
     if ($special_color) {
         $line .= "<font color=\"$color[11]\">";
     }
     if ( $mailbox == 'INBOX' ) {
+    		$line .= '<img src="../images/inbox.png" border="0" height="16" width="16" style="vertical-align: bottom;" alt="'. _("INBOX") .'" title="'. _("INBOX") .'">';
         $line .= _("INBOX");
+    } elseif ( $real_box == $draft_folder){
+    		$line .= '<img src="../images/draft.png" border="0" height="16" width="16" style="vertical-align: middle;" alt="'. $mailbox .'" title="'. $mailbox .'">';
+        $line .= str_replace(array(' ','<','>'),array('&nbsp;','&lt;','&gt;'),$mailbox);
+    } elseif ( $real_box == $sent_folder){
+    		$line .= '<img src="../images/senti.png" border="0" height="16" width="16" style="vertical-align: middle;" alt="'. $mailbox .'" title="'. $mailbox .'">';
+        $line .= str_replace(array(' ','<','>'),array('&nbsp;','&lt;','&gt;'),$mailbox);
+    } elseif ( $real_box == $trash_folder){
+    		$line .= '<img src="../images/delitem.png" border="0" height="16" width="16" style="vertical-align: middle;" alt="'. $mailbox .'" title="'. $mailbox .'">';
+        $line .= str_replace(array(' ','<','>'),array('&nbsp;','&lt;','&gt;'),$mailbox);
     } else {
-        $line .= str_replace(' ','&nbsp;',$mailbox);
+    		$line .= '<img src="../images/folder.png" border="0" height="16" width="16" style="vertical-align: middle;" alt="'. $mailbox .'" title="'. $mailbox .'">';
+        $line .= str_replace(array(' ','<','>'),array('&nbsp;','&lt;','&gt;'),$mailbox);
     }
     if ($special_color == TRUE)
         $line .= '</font>';
@@ -173,9 +184,9 @@ function create_collapse_link($boxnum) {
     $link = '<a target="left" style="text-decoration:none" ' .
             'href="left_main.php?';
     if ($boxes[$boxnum]['collapse'] == SM_BOX_COLLAPSED) {
-        $link .= "unfold=$mailbox\"><IMG src=\"../images/plus.gif\" border=\"0\" height=\"7\" width=\"7\">";
+        $link .= "unfold=$mailbox\"><IMG src=\"../images/plus.png\" border=\"0\" height=\"7\" width=\"7\">";
     } else {
-        $link .= "fold=$mailbox\"><IMG src=\"../images/minus.gif\" border=\"0\" height=\"7\" width=\"7\">";
+        $link .= "fold=$mailbox\"><IMG src=\"../images/minus.png\" border=\"0\" height=\"7\" width=\"7\">";
     }
     $link .= '</a>';
 
@@ -283,7 +294,8 @@ function is_parent_box($curbox_name, $parbox_name) {
 
 function listBoxes ($boxes, $j=0 ) {
     global $data_dir, $username, $startmessage, $color, $unseen_notify, $unseen_type,
-    $move_to_trash, $trash_folder, $collapse_folders;
+        $move_to_trash, $trash_folder, $collapse_folders, $use_special_folder_color;
+
     $pre = '';
     $end = '';
     $collapse = false;
@@ -303,7 +315,7 @@ function listBoxes ($boxes, $j=0 ) {
     	    if ($boxes->total) {
 		$numMessages = $boxes->total;
         	$unseen_string = "<font color=\"$color[11]\">($unseen/$numMessages)</font>";
-	    }	    
+	    }
 	} else $unseen = 0;
 
 
@@ -357,27 +369,27 @@ function listBoxes ($boxes, $j=0 ) {
 
 	$font = '';
 	$fontend = '';
-	if ($boxes->is_special) {
+	if ($use_special_folder_color && $boxes->is_special) {
     	    $font = "<font color=\"$color[11]\">";
-	    $fontend = "</font>";    
+	    $fontend = "</font>";
 	}
-	
-	if (!$boxes->is_root) { 
-	    echo "" . $pre .$font. $boxes->mailboxname_sub .$fontend . $end. '<br />';
+
+	if (!$boxes->is_root) {
+	    echo "" . $pre .$font. str_replace(array(' ','<','>'),array('&nbsp;','&lt;','&gt;'),$boxes->mailboxname_sub) .$fontend . $end. '<br />';
 	    $j++;
 	}
 	if (!$collapse || $boxes->is_root) {
     	    for ($i = 0; $i <count($boxes->mbxs); $i++) {
     		listBoxes($boxes->mbxs[$i],$j);
     	    }
-	}    
-	
+	}
+
     }
 }
 
 function ListAdvancedBoxes ($boxes, $mbx, $j='ID.0000' ) {
     global $data_dir, $username, $startmessage, $color, $unseen_notify, $unseen_type,
-    $move_to_trash, $trash_folder, $collapse_folders;
+        $move_to_trash, $trash_folder, $collapse_folders, $use_special_folder_color;
 
     /* use_folder_images only works if the images exist in ../images */
     $use_folder_images = true;
@@ -385,7 +397,7 @@ function ListAdvancedBoxes ($boxes, $mbx, $j='ID.0000' ) {
     $pre = '';
     $end = '';
     $collapse = false;
-    
+
     if ($boxes) {
 	$mailbox = $boxes->mailboxname_full;
 	$mailboxURL = urlencode($mailbox);
@@ -398,16 +410,16 @@ function ListAdvancedBoxes ($boxes, $mbx, $j='ID.0000' ) {
     	    if ($boxes->total) {
 		$numMessages = $boxes->total;
         	$unseen_string = "<font color=\"$color[11]\">($unseen/$numMessages)</font>";
-	    }	    
+	    }
 	} else $unseen = 0;
 
 	/* If there are unseen message, bold the line. */
 	if ($unseen > 0) { $pre .= '<b>'; }
 
 	/* color special boxes */
-	if ($boxes->is_special) {
+	if ($use_special_folder_color && $boxes->is_special) {
     	    $pre .= "<font color=\"$color[11]\">";
-	    $end .= '</font>';    
+	    $end .= '</font>';
 	}
 
 	/* If there are unseen message, close bolding. */
@@ -438,19 +450,19 @@ function ListAdvancedBoxes ($boxes, $mbx, $j='ID.0000' ) {
 	if (!$boxes->is_root) {
 	    if ($use_folder_images) {
 	      if ($boxes->is_inbox) {
-		$folder_img = '../images/inbox.gif';
+		$folder_img = '../images/inbox.png';
 	      } else if ($boxes->is_sent) {
-		$folder_img = '../images/senti.gif';
+		$folder_img = '../images/senti.png';
 	      } else if ($boxes->is_trash) {
-		$folder_img = '../images/delitem.gif';
+		$folder_img = '../images/delitem.png';
 	      } else if ($boxes->is_draft) {
-		$folder_img = '../images/draft.gif';
-	      } else $folder_img = '../images/folder.gif';
+		$folder_img = '../images/draft.png';
+	      } else $folder_img = '../images/folder.png';
 	      $folder_img = '&nbsp;<img src="'.$folder_img.'" height="15" valign="center" />&nbsp;';
 	    } else $folder_img = '';
 	    if (!isset($boxes->mbxs[0])) {
 	        echo '   ' . html_tag( 'div',
-	                        $pre . $folder_img . $boxes->mailboxname_sub . $end ,
+	                        $pre . $folder_img . str_replace(array(' ','<','>'),array('&nbsp;','&lt;','&gt;'),$boxes->mailboxname_sub) . $end ,
 	                'left', '', 'class="mbx_sub" id="' .$j. '"' )
 		        . "\n";
 	    } else {
@@ -470,9 +482,9 @@ function ListAdvancedBoxes ($boxes, $mbx, $j='ID.0000' ) {
     			$collapse = ($collapse == '' ? SM_BOX_UNCOLLAPSED : $collapse);
 		    }
 		    if ($collapse) {
-    			$link = '<a href="javascript:void(0)">'." <img src=\"../images/plus.gif\" border=\"1\" id=$j onclick=\"hidechilds(this)\" /></a>";
+    			$link = '<a href="javascript:void(0)">'." <img src=\"../images/plus.png\" border=\"1\" id=$j onclick=\"hidechilds(this)\" /></a>";
 		    } else {
-    			$link = '<a href="javascript:void(0)">'."<img src=\"../images/minus.gif\" border=\"1\" id=$j onclick=\"hidechilds(this)\" /></a>";
+    			$link = '<a href="javascript:void(0)">'."<img src=\"../images/minus.png\" border=\"1\" id=$j onclick=\"hidechilds(this)\" /></a>";
 		    }
 		    $collapse_link = $link;
 		} else $collapse_link='';
@@ -516,6 +528,7 @@ sqgetGlobalVar('onetimepad', $onetimepad, SQ_SESSION);
 
 sqgetGlobalVar('fold', $fold, SQ_GET);
 sqgetGlobalVar('unfold', $unfold, SQ_GET);
+sqgetGlobalVar('auto_create_done',$auto_create_done,SQ_SESSION);
 
 /* end globals */
 
@@ -535,21 +548,21 @@ if (isset($left_refresh) && ($left_refresh != '') &&
 }
 
 /**
- * $advanced_tree and $oldway are boolean vars which are default set to default 
- * SM behaviour. 
- * Setting $oldway to false causes left_main.php to use the new  experimental 
+ * $advanced_tree and $oldway are boolean vars which are default set to default
+ * SM behaviour.
+ * Setting $oldway to false causes left_main.php to use the new  experimental
  * way of getting the mailbox-tree.
- * Setting $advanced tree to true causes SM to display a experimental 
+ * Setting $advanced tree to true causes SM to display a experimental
  * mailbox-tree with dhtml behaviour.
- * It only works on browsers which supports css and javascript. The used 
- * javascript is experimental and doesn't support all browsers. It is tested on 
+ * It only works on browsers which supports css and javascript. The used
+ * javascript is experimental and doesn't support all browsers. It is tested on
  * IE6 an Konquerer 3.0.0-2.
  * In the function ListAdvancedBoxes there is another var $use_folder_images.
  * setting this to true is only usefull if the images exists in ../images.
- * 
+ *
  * Feel free to experiment with the code and report bugs and enhancements
  * to marc@its-projects.nl
- **/ 
+ **/
 
 $advanced_tree = false; /* set this to true if you want to see a nicer mailboxtree */
 $oldway = true; /* default SM behaviour */
@@ -569,12 +582,12 @@ $xtra .= <<<ECHO
 	       if(ele.style.display == "none") {
                   ele.style.display = "block";
 	          ele.style.visibility = "visible"
-                  el.src="../images/minus.gif";
+                  el.src="../images/minus.png";
                   document.all[form_id].value=0;
                } else {
                   ele.style.display = "none";
 	          ele.style.visibility = "hidden"
-	          el.src="../images/plus.gif";
+	          el.src="../images/plus.png";
 	          document.all[form_id].value=1;
 	       }
 	    }
@@ -584,18 +597,18 @@ $xtra .= <<<ECHO
 	       if(ele.style.display == "none") {
 	          ele.style.display = "block";
 	          ele.style.visibility = "visible"
-	          el.src="../images/minus.gif";
+	          el.src="../images/minus.png";
                   document.getElementById(form_id).value=0;
 	       } else {
 	          ele.style.display = "none";
 	          ele.style.visibility = "hidden"
-	          el.src="../images/plus.gif";
+	          el.src="../images/plus.png";
                   document.getElementById(form_id).value=1;
 	       }
-	    }   
+	    }
 	}
    }
-   
+
    function preload() {
      if (!document.images) return;
      var ar = new Array();
@@ -604,8 +617,8 @@ $xtra .= <<<ECHO
         ar[i] = new Image();
 	ar[i].src = arguments[i];
      }
-   }        
-	    	  
+   }
+
    function buttonover(el,on) {
       if (!on) {
          el.style.borderColor="blue";}
@@ -614,14 +627,14 @@ $xtra .= <<<ECHO
    }
 
    function buttonclick(el,on) {
-      if (!on) { 
+      if (!on) {
          el.style.border="groove"}
       else {
          el.style.border="ridge";}
    }
 
    function hideframe(hide) {
-   
+
 ECHO;
 $xtra .= "      left_size = \"$left_size\";\n";
 $xtra .= <<<ECHO
@@ -637,7 +650,7 @@ $xtra .= <<<ECHO
 	leftbutton = document.getElementById("showf");
       } else {
         return false;
-      }	
+      }
       if(hide) {
          new_col = calc_col("20");
          masterf.cols = new_col;
@@ -650,16 +663,16 @@ $xtra .= <<<ECHO
 	 document.body.style.overflow='';
 	 leftbutton.style.display='none';
 	 leftcontent.style.display='block';
-	 
+
       }
    }
-   
+
    function calc_col(c_w) {
 
 ECHO;
    if ($location_of_bar == 'right') {
        $xtra .= '     right=true;';
-   } else {    
+   } else {
        $xtra .= '     right=false;';
    }
    $xtra .= "\n";
@@ -670,8 +683,8 @@ $xtra .= <<<ECHO
          new_col = c_w+',*';
      }
      return new_col;
-   }	 
-         
+   }
+
    function resizeframe(direction) {
      if (document.all) {
     	masterf = window.parent.document.all["fs1"];
@@ -680,32 +693,32 @@ $xtra .= <<<ECHO
      } else {
         return false;
      }
-     
+
 ECHO;
    if ($location_of_bar == 'right') {
        $xtra .= '  colPat=/^\*,(\d+)$/;';
-   } else {    
+   } else {
        $xtra .= '  colPat=/^(\d+),.*$/;';
    }
    $xtra .= "\n";
-  
+
 $xtra .= <<<ECHO
      old_col = masterf.cols;
      colPat.exec(old_col);
-     
+
      if (direction) {
         new_col_width = parseInt(RegExp.$1) + 25;
-	
+
      } else {
         if (parseInt(RegExp.$1) > 35) {
            new_col_width = parseInt(RegExp.$1) - 25;
         }
      }
-     masterf.cols = calc_col(new_col_width);	
+     masterf.cols = calc_col(new_col_width);
    }
 
 //-->
-   
+
 </script>
 
 ECHO;
@@ -798,7 +811,7 @@ ECHO;
 displayHtmlHeader( 'SquirrelMail', $xtra );
 
 /* If requested and not yet complete, attempt to autocreate folders. */
-if ($auto_create_special && !isset($auto_create_done)) {
+if ($auto_create_special && !$auto_create_done) {
     $autocreate = array($sent_folder, $trash_folder, $draft_folder);
     foreach( $autocreate as $folder ) {
         if (($folder != '') && ($folder != 'none')) {
@@ -813,13 +826,24 @@ if ($auto_create_special && !isset($auto_create_done)) {
     /* Let the world know that autocreation is complete! Hurrah! */
     $auto_create_done = TRUE;
     sqsession_register($auto_create_done, 'auto_create_done');
+    /* retrieve the mailboxlist. We do this at a later stage again but if
+       the right_frame loads faster then the second call retrieves a cached
+       version of the mailboxlist without the newly created folders.
+       The second parameter forces a non cached mailboxlist return.
+     */
+    if ($advanced_tree) {
+        // do nothing, caching not seported yet.
+        //$boxes = sqimap_mailbox_tree($imapConnection);
+    } else {
+        $boxes = sqimap_mailbox_list($imapConnection,true);
+    }
 }
 
 echo "\n<body bgcolor=\"$color[3]\" text=\"$color[6]\" link=\"$color[6]\" vlink=\"$color[6]\" alink=\"$color[6]\">\n";
 
 do_hook('left_main_before');
 if ($advanced_tree) {
-   /* nice future feature, needs layout !! volunteers?   */  
+   /* nice future feature, needs layout !! volunteers?   */
    $right_pos = $left_size - 20;
    echo '<div style="position:absolute;top:0;border=solid;border-width:0.1em;border-color:blue;"><div ID="hidef" style="width=20;font-size:12"><A HREF="javascript:hideframe(true)"><b><<</b></a></div>';
    echo '<div ID="showf" style="width=20;font-size:12;display:none;"><a href="javascript:hideframe(false)"><b>>></b></a></div>';
@@ -828,9 +852,9 @@ if ($advanced_tree) {
    echo '<div ID="leftframe"><br /><br />';
 }
 
-echo "\n\n" . html_tag( 'table', '', 'left', '', 'border="0" cellspacing="0" cellpadding="0" width="99%"' ) . 
-    html_tag( 'tr' ) . 
-    html_tag( 'td', '', 'left' ) . 
+echo "\n\n" . html_tag( 'table', '', 'left', '', 'border="0" cellspacing="0" cellpadding="0" width="99%"' ) .
+    html_tag( 'tr' ) .
+    html_tag( 'td', '', 'left' ) .
     '<center><font size="4"><b>'. _("Folders") . "</b><br /></font>\n\n";
 
 if ($date_format != 6) {
@@ -849,6 +873,9 @@ if ($date_format != 6) {
     }
 
     switch( $date_format ) {
+    case 0:
+	$clk = date('Y-m-d '.$hr. ' T', time());
+	break;
     case 1:
         $clk = date('m/d/y '.$hr, time());
         break;
@@ -860,7 +887,7 @@ if ($date_format != 6) {
         $clk = date($hr, time());
         break;
     default:
-        $clk = substr( getDayName( date( 'w', time() ) ), 0, 3 ) . date( ', ' . $hr, time() );
+        $clk = getDayAbrv( date( 'w', time() ) ) . date( ', ' . $hr, time() );
     }
     $clk = str_replace(' ','&nbsp;',$clk);
 
@@ -871,6 +898,7 @@ if ($date_format != 6) {
 /* Next, display the refresh button. */
 echo '<small>(<a href="../src/left_main.php" target="left">'.
      _("refresh folder list") . '</a>)</small></center><br />';
+// for SM 1.4.3:  _("Check mail")
 
 /* Lastly, display the folder list. */
 if ( $collapse_folders ) {
@@ -883,8 +911,11 @@ if ( $collapse_folders ) {
 }
 
 if ($oldway) {  /* normal behaviour SM */
- 
-$boxes = sqimap_mailbox_list($imapConnection);
+
+sqgetGlobalVar('force_refresh',$force_refresh,SQ_GET);
+if (!isset($boxes)) { // auto_create_done
+    $boxes = sqimap_mailbox_list($imapConnection,$force_refresh);
+}
 /* Prepare do do out collapsedness and visibility computation. */
 $curbox = 0;
 $boxcount = count($boxes);
@@ -937,16 +968,19 @@ for ($i = 0; $i < count($boxes); $i++) {
 
         /* Output the line for this folder. */
         echo $line;
+
+
+
     }
 }
-} else {  /* expiremental code */ 
+} else {  /* expiremental code */
     $boxes = sqimap_mailbox_tree($imapConnection);
     if (isset($advanced_tree) && $advanced_tree) {
 	echo '<form name="collapse" action="left_main.php" method="post" ' .
             'enctype="multipart/form-data"'."\n";
 	echo '<small><button type="submit" class="button" onmouseover="buttonover(this,true)" onmouseout="buttonover(this,false)" onmousedown="buttonclick(this,true)" onmouseup="buttonclick(this,false)">'. _("Save folder tree") .'</button><br /><br />';
 	echo '<div id="mailboxes" class="mailboxes">'."\n\n";
-	if (!isset($mbx)) $mbx=NULL; 
+	if (!isset($mbx)) $mbx=NULL;
 	    ListAdvancedBoxes($boxes, $mbx);
 	echo '</div></small>'."\n";
 	echo '</form>'."\n";
@@ -954,6 +988,13 @@ for ($i = 0; $i < count($boxes); $i++) {
 	ListBoxes($boxes);
     }
 } /* if ($oldway) else ... */
+
+       /* Next, display the refresh button. */
+//       echo '<br><center><small>(<a href="../src/left_main.php?force_refresh=1" target="left">'.
+//          _("refresh folder list") . '</a>)</small></center><br />';
+
+
+
 do_hook('left_main_after');
 sqimap_logout($imapConnection);
 
